Struct nix::mount::MntFlags [−]
pub struct MntFlags { /* fields omitted */ }Methods
impl MntFlags
impl MntFlagspub fn empty() -> MntFlags
pub fn empty() -> MntFlagsReturns an empty set of flags.
pub fn all() -> MntFlags
pub fn all() -> MntFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<MntFlags>
pub fn from_bits(bits: c_int) -> Option<MntFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> MntFlags
pub fn from_bits_truncate(bits: c_int) -> MntFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: MntFlags) -> bool
pub fn intersects(&self, other: MntFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: MntFlags) -> bool
pub fn contains(&self, other: MntFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: MntFlags)
pub fn insert(&mut self, other: MntFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: MntFlags)
pub fn remove(&mut self, other: MntFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: MntFlags)
pub fn toggle(&mut self, other: MntFlags)Toggles the specified flags in-place.